from typing import List, Dict

from blue_options.terminal import show_usage, xtra

urls: Dict[str, str] = {
    "github": "https://github.com/ChenHongruixuan/BRIGHT",
    "huggingface": "https://huggingface.co/datasets/Kullervo/BRIGHT",
}


def help_browse(
    tokens: List[str],
    mono: bool,
) -> str:
    options = " | ".join(urls.keys())

    return show_usage(
        [
            "@fusion",
            "bright",
            "browse",
            f"[{options}]",
        ],
        "browse bright.",
        mono=mono,
    )


def help_install(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("recreate_env", mono=mono)

    return show_usage(
        [
            "@fusion",
            "bright",
            "install",
            f"[{options}]",
        ],
        "browse blue_plugin.",
        mono=mono,
    )


help_functions = {
    "browse": help_browse,
    "install": help_install,
}



from typing import List

from abcli.host import signature as abcli_signature

from blue_fusion import fullname


def signature() -> List[str]:
    return [
        fullname(),
    ] + abcli_signature()



import os

from blue_objects import file, README

from blue_fusion import NAME, VERSION, ICON, REPO_NAME


items = []


def build():
    return README.build(
        items=items,
        path=os.path.join(file.path(__file__), ".."),
        ICON=ICON,
        NAME=NAME,
        VERSION=VERSION,
        REPO_NAME=REPO_NAME,
    )



NAME = "blue_fusion"

ICON = "🔮"

DESCRIPTION = f"{ICON} 2025 IEEE GRSS Data Fusion Contest"

VERSION = "4.12.1"

REPO_NAME = "blue-fusion"

MARQUEE = "https://github.com/kamangir/assets/raw/main/blue-fusion/marquee.png?raw=true"

ALIAS = "@fusion"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
